@@ -1,10 +1,12 @@
+from __future__ import absolute_import, unicode_literals
+
 import random
 import string
 
 from django.db import models
 from django.db import IntegrityError
 from django.utils.translation import ugettext_lazy as _
-
+from django.utils.encoding import force_text, python_2_unicode_compatible
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.contenttypes import generic
 
@@ -12,6 +14,7 @@ import logging
 logger = logging.getLogger(__name__)
 
 
+@python_2_unicode_compatible
 class MailConfirmation(models.Model):
     """
     Handles a confirmation token randomly generated
@@ -52,5 +55,5 @@ class MailConfirmation(models.Model):
         logger.error("Unable to generate mail_confirmation unique id, you could have won the lottery!")
         raise IntegrityError("mail_confirmation save error")
 
-    def __unicode__(self):
+    def __str__(self):
         return self.confirmed
